runSummerChildApp: Load questions and results categorisation from JSON file, run...

View source: R/runSummerChildApp.R

runSummerChildAppR Documentation

Load questions and results categorisation from JSON file, run survey and then present results and recommendations based on survey responses

Description

Load questions and results categorisation from JSON file, run survey and then present results and recommendations based on survey responses

Usage

runSummerChildApp()

summerscope/summerchildr documentation built on March 29, 2022, 11:06 p.m.